@@ -19,8 +19,8 @@ import gdb
 import os
 import os.path
 
-pythondir = '/builder/mvebu_cortexa53/build/staging_dir/toolchain-aarch64_cortex-a53_gcc-7.3.0_musl/share/gcc-7.3.0/python'
-libdir = '/builder/mvebu_cortexa53/build/staging_dir/toolchain-aarch64_cortex-a53_gcc-7.3.0_musl/aarch64-openwrt-linux-musl/lib'
+pythondir = '/builder/shared-workdir/build/staging_dir/toolchain-aarch64_cortex-a53_gcc-7.5.0_musl/share/gcc-7.5.0/python'
+libdir = '/builder/shared-workdir/build/staging_dir/toolchain-aarch64_cortex-a53_gcc-7.5.0_musl/aarch64-openwrt-linux-musl/lib'
 
 # This file might be loaded when there is no current objfile.  This
 # can happen if the user loads it manually.  In this case we don't
